"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CrosslabConnectionTransport = void 0;
const isomorphic_ws_1 = __importDefault(require("isomorphic-ws"));
const tiny_typed_emitter_1 = require("tiny-typed-emitter");
const logging_js_1 = require("./logging.js");
class CrosslabConnectionTransport extends tiny_typed_emitter_1.TypedEmitter {
    get ws() {
        if (this._ws) {
            return this._ws;
        }
        else {
            throw new Error("CrosslabConnectionTransport must be called with connect() first");
        }
    }
    constructor(connectOptions) {
        super();
        this.options = connectOptions;
    }
    async connect(logginTransport) {
        this._ws = new isomorphic_ws_1.default(this.options.endpoint);
        this.ws.onopen = () => {
            this.ws.send(JSON.stringify({
                messageType: 'authenticate',
                deviceUrl: this.options.id,
                token: this.options.token,
            }));
            logginTransport._set_upstream(info => this.ws.send(JSON.stringify({ messageType: 'logging', content: info })));
        };
        const p = new Promise((resolve, reject) => {
            this.ws.onmessage = authenticationEvent => {
                const authenticationMessage = JSON.parse(authenticationEvent.data);
                if (authenticationMessage.messageType === 'authenticate') {
                    if (authenticationMessage.authenticated) {
                        resolve();
                    }
                    else
                        reject('Authentication failed');
                }
                else {
                    reject(`Expected message with messageType 'authenticate', received ${authenticationMessage.messageType}`);
                }
            };
        });
        this.ws.onclose = event => {
            logging_js_1.logger.log('info', 'ws closed', { reason: event.reason, code: event.code });
        };
        this.ws.onerror = event => {
            logging_js_1.logger.log('error', event.message, { type: event.type, error: event.error });
        };
        await p;
        this.ws.onmessage = event => {
            const message = JSON.parse(event.data);
            this.emit("message", message);
        };
    }
    send(data) {
        this.ws.send(data);
    }
}
exports.CrosslabConnectionTransport = CrosslabConnectionTransport;
;
//# sourceMappingURL=deviceConnectionTransport.js.map