import WebSocket from 'isomorphic-ws';
import { TypedEmitter } from 'tiny-typed-emitter';
import { logger } from "./logging.js";
export class CrosslabConnectionTransport extends TypedEmitter {
    get ws() {
        if (this._ws) {
            return this._ws;
        }
        else {
            throw new Error("CrosslabConnectionTransport must be called with connect() first");
        }
    }
    constructor(connectOptions) {
        super();
        this.options = connectOptions;
    }
    async connect(logginTransport) {
        this._ws = new WebSocket(this.options.endpoint);
        this.ws.onopen = () => {
            this.ws.send(JSON.stringify({
                messageType: 'authenticate',
                deviceUrl: this.options.id,
                token: this.options.token,
            }));
            logginTransport._set_upstream(info => this.ws.send(JSON.stringify({ messageType: 'logging', content: info })));
        };
        const p = new Promise((resolve, reject) => {
            this.ws.onmessage = authenticationEvent => {
                const authenticationMessage = JSON.parse(authenticationEvent.data);
                if (authenticationMessage.messageType === 'authenticate') {
                    if (authenticationMessage.authenticated) {
                        resolve();
                    }
                    else
                        reject('Authentication failed');
                }
                else {
                    reject(`Expected message with messageType 'authenticate', received ${authenticationMessage.messageType}`);
                }
            };
        });
        this.ws.onclose = event => {
            logger.log('info', 'ws closed', { reason: event.reason, code: event.code });
        };
        this.ws.onerror = event => {
            logger.log('error', event.message, { type: event.type, error: event.error });
        };
        await p;
        this.ws.onmessage = event => {
            const message = JSON.parse(event.data);
            this.emit("message", message);
        };
    }
    send(data) {
        this.ws.send(data);
    }
}
;
//# sourceMappingURL=deviceConnectionTransport.js.map