export class CrosslabTransport {
    constructor() {
        this.buffer = [];
        this.upstream = () => { };
    }
    log(info) {
        try {
            this.upstream(info);
        }
        catch (_e) {
            this.buffer.push(info);
        }
    }
    _set_upstream(upstream) {
        this.upstream = upstream;
        const bufferCopy = this.buffer.slice();
        this.buffer = [];
        bufferCopy.forEach(info => this.log(info));
    }
}
export const crosslabTransport = new CrosslabTransport();
export class Logger {
    constructor(options) {
        this.levels = {
            fatal: 0,
            error: 1,
            warn: 2,
            info: 3,
            debug: 4,
            trace: 5,
        };
        this.transports = options.transports ? options.transports : [];
        if (options.levels) {
            this.levels = options.levels;
        }
        this.level =
            options.level ??
                Object.entries(this.levels)
                    .sort(([_1, value_1], [_2, value_2]) => value_1 - value_2)
                    .slice(-1)[0][0];
        if (this.levels[this.level] === undefined) {
            throw new Error(`Invalid log level: ${this.level}`);
        }
    }
    log(level, message, meta) {
        if (typeof message === 'string') {
            meta = { message, ...meta };
        }
        else {
            meta = { ...message, ...meta };
        }
        if (this.levels[level] <= this.levels[this.level]) {
            const info = { level, ...meta };
            this.transports.forEach(transport => transport.log(info));
        }
    }
}
export const logger = new Logger({
    transports: [crosslabTransport],
    levels: {
        fatal: 0,
        error: 1,
        warn: 2,
        info: 3,
        debug: 4,
        trace: 5,
    },
});
//# sourceMappingURL=logging.js.map