import { TypedEmitter } from 'tiny-typed-emitter';
import { DeviceConnectionTransport } from './deviceConnectionTransport.js';
import { CreatePeerConnectionMessage } from './deviceMessages.js';
import { PeerConnection } from './peer/connection.js';
import { Service } from './service.js';
export interface DeviceHandlerEvents {
    connectionsChanged(): void;
    configuration(configuration: {
        [k: string]: unknown;
    }): void;
    experimentStatusChanged(status: {
        status: 'created' | 'booked' | 'setup' | 'running' | 'failed' | 'closed';
        message?: string;
    }): void;
}
type FullStateType<ServiceT extends Service> = {
    [serviceId in ServiceT['serviceId']]: Extract<ServiceT, {
        serviceId: serviceId;
    }>['get_state'] extends () => infer R ? R : never;
};
export declare class DeviceHandler<ServiceT extends Service> extends TypedEmitter<DeviceHandlerEvents> {
    id: string;
    connections: Map<string, PeerConnection>;
    services: {
        [serviceId in ServiceT['serviceId']]: Extract<ServiceT, {
            serviceId: serviceId;
        }>;
    };
    transport?: DeviceConnectionTransport;
    connectionConstuctors: Map<string, (message: CreatePeerConnectionMessage) => PeerConnection>;
    fullstatemap: Map<string, any[]>;
    stateEvaluator?: (input: FullStateType<ServiceT>, output: FullStateType<ServiceT>) => boolean;
    evaluateState(input: any[], output: any): void;
    handleDataUpstream(data: any): {
        fullstate: {
            [x: string]: any;
        };
        data: any;
    };
    handleDataDownstream(data: any): any;
    constructor(...services: ServiceT[]);
    setErrorState(stateEvaluator: (input: FullStateType<ServiceT>, output: FullStateType<ServiceT>) => boolean): void;
    connect(transport: DeviceConnectionTransport): Promise<void>;
    connect(connectOptions: {
        endpoint: string;
        id: string;
        token: string;
    }): Promise<void>;
    private _connect;
    addService(service: ServiceT): void;
    private handleCreatePeerConnectionMessage;
    private handleSignalingMessage;
    private handleClosePeerConnectionMessage;
    private handleConfigurationMessage;
    private handleExperimentStatusChangedMessage;
    getServiceMeta(): {
        serviceId: string;
        serviceType: string;
        serviceDirection: import("./service.js").ServiceDirection;
    }[];
}
export {};
//# sourceMappingURL=deviceHandler.d.ts.map