import { TypedEmitter } from 'tiny-typed-emitter';
import { SignalingMessage } from '../deviceMessages.js';
import { Channel } from './channel.js';
import { PeerConnection, PeerConnectionEvents, ServiceConfig } from './connection.js';
interface RTCSignalingCandidateMessage extends SignalingMessage {
    signalingType: 'candidate';
    content: RTCIceCandidate;
}
interface RTCSignalingOfferMessage extends SignalingMessage {
    signalingType: 'offer';
    content: RTCSessionDescriptionInit;
}
interface RTCSignalingAnswerMessage extends SignalingMessage {
    signalingType: 'answer';
    content: RTCSessionDescriptionInit;
}
interface RTCSignalingOptionsMessage extends SignalingMessage {
    signalingType: 'options';
    content: {
        canTrickle: boolean;
    };
}
export type RTCSignalingMessage = RTCSignalingCandidateMessage | RTCSignalingOfferMessage | RTCSignalingAnswerMessage | RTCSignalingOptionsMessage;
export declare class WebRTCPeerConnection extends TypedEmitter<PeerConnectionEvents> implements PeerConnection {
    private signalingQueue;
    private candidateQueue;
    private isProcessing;
    private role?;
    private _state;
    private receivingChannels;
    private transeiverMap;
    private mediaChannelMap;
    private trickleIce;
    tiebreaker: boolean;
    pc: RTCPeerConnection;
    state: 'new' | 'connecting' | 'connected' | 'disconnected' | 'failed' | 'closed';
    private iceCandidateResolver?;
    private optionsReceived?;
    private optionsReceivedResolver?;
    channelExtension: {
        upstream: ((data: any) => any);
        downstream: ((data: any) => any);
    } | undefined;
    private onnegotiationneeded;
    private onicecandidate;
    private onicegatheringstatechange;
    constructor(configuration: RTCConfiguration);
    transmit(serviceConfig: ServiceConfig, id: string, channel: Channel): void;
    receive(serviceConfig: ServiceConfig, id: string, channel: Channel): void;
    handleSignalingMessage(msg: RTCSignalingMessage): Promise<void>;
    private executeQueue;
    connect(): Promise<void>;
    private handleOffer;
    private handleAnswer;
    private handleIceCandidate;
    private handleOptions;
    teardown(): void;
    private makeOffer;
    private makeAnswer;
    private acceptAnswer;
    private addIceCandidate;
    private sendIceCandidate;
    private create_label;
    private modifySDP;
    private matchMediaChannels;
    private createMediaChannels;
}
export {};
//# sourceMappingURL=webrtc-connection.d.ts.map